package jalview.datamodel.features;

import java.util.HashMap;
import java.util.Map;

/**
 * A class to model one source of feature data, including metadata about
 * attributes of features
 * 
 * @author gmcarstairs
 *
 */
public class FeatureSource implements FeatureSourceI
{
  private String name;

  private Map<String, String> attributeNames;
  
  private Map<String, FeatureAttributeType> attributeTypes;
  
  /**
   * Constructor
   * 
   * @param theName
   */
  public FeatureSource(String theName)
  {
    this.name = theName;
    attributeNames = new HashMap<>();
    attributeTypes = new HashMap<>();
  }

  /**
   * {@inheritDoc}
   */
  @Override
  public String getName()
  {
    return name;
  }

  /**
   * {@inheritDoc}
   */
  @Override
  public String getAttributeName(String attributeId)
  {
    return attributeNames.get(attributeId);
  }

  /**
   * {@inheritDoc}
   */
  @Override
  public FeatureAttributeType getAttributeType(String attributeId)
  {
    return attributeTypes.get(attributeId);
  }

  /**
   * {@inheritDoc}
   */
  @Override
  public void setAttributeName(String id, String attName)
  {
    attributeNames.put(id, attName);
  }

  /**
   * {@inheritDoc}
   */
  @Override
  public void setAttributeType(String id, FeatureAttributeType type)
  {
    attributeTypes.put(id, type);
  }

}
